// Copyright 2020 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     https://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by client-gen. DO NOT EDIT.

package v1alpha1

import (
	"context"
	"time"

	v1alpha1 "github.com/google/kf/v2/pkg/apis/kf/v1alpha1"
	scheme "github.com/google/kf/v2/pkg/client/kf/clientset/versioned/scheme"
	v1 "k8s.io/apimachinery/pkg/apis/meta/v1"
	types "k8s.io/apimachinery/pkg/types"
	watch "k8s.io/apimachinery/pkg/watch"
	rest "k8s.io/client-go/rest"
)

// ScalesGetter has a method to return a ScaleInterface.
// A group's client should implement this interface.
type ScalesGetter interface {
	Scales(namespace string) ScaleInterface
}

// ScaleInterface has methods to work with Scale resources.
type ScaleInterface interface {
	Create(ctx context.Context, scale *v1alpha1.Scale, opts v1.CreateOptions) (*v1alpha1.Scale, error)
	Update(ctx context.Context, scale *v1alpha1.Scale, opts v1.UpdateOptions) (*v1alpha1.Scale, error)
	Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
	DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
	Get(ctx context.Context, name string, opts v1.GetOptions) (*v1alpha1.Scale, error)
	List(ctx context.Context, opts v1.ListOptions) (*v1alpha1.ScaleList, error)
	Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
	Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1alpha1.Scale, err error)
	ScaleExpansion
}

// scales implements ScaleInterface
type scales struct {
	client rest.Interface
	ns     string
}

// newScales returns a Scales
func newScales(c *KfV1alpha1Client, namespace string) *scales {
	return &scales{
		client: c.RESTClient(),
		ns:     namespace,
	}
}

// Get takes name of the scale, and returns the corresponding scale object, and an error if there is any.
func (c *scales) Get(ctx context.Context, name string, options v1.GetOptions) (result *v1alpha1.Scale, err error) {
	result = &v1alpha1.Scale{}
	err = c.client.Get().
		Namespace(c.ns).
		Resource("scales").
		Name(name).
		VersionedParams(&options, scheme.ParameterCodec).
		Do(ctx).
		Into(result)
	return
}

// List takes label and field selectors, and returns the list of Scales that match those selectors.
func (c *scales) List(ctx context.Context, opts v1.ListOptions) (result *v1alpha1.ScaleList, err error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	result = &v1alpha1.ScaleList{}
	err = c.client.Get().
		Namespace(c.ns).
		Resource("scales").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Do(ctx).
		Into(result)
	return
}

// Watch returns a watch.Interface that watches the requested scales.
func (c *scales) Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	opts.Watch = true
	return c.client.Get().
		Namespace(c.ns).
		Resource("scales").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Watch(ctx)
}

// Create takes the representation of a scale and creates it.  Returns the server's representation of the scale, and an error, if there is any.
func (c *scales) Create(ctx context.Context, scale *v1alpha1.Scale, opts v1.CreateOptions) (result *v1alpha1.Scale, err error) {
	result = &v1alpha1.Scale{}
	err = c.client.Post().
		Namespace(c.ns).
		Resource("scales").
		VersionedParams(&opts, scheme.ParameterCodec).
		Body(scale).
		Do(ctx).
		Into(result)
	return
}

// Update takes the representation of a scale and updates it. Returns the server's representation of the scale, and an error, if there is any.
func (c *scales) Update(ctx context.Context, scale *v1alpha1.Scale, opts v1.UpdateOptions) (result *v1alpha1.Scale, err error) {
	result = &v1alpha1.Scale{}
	err = c.client.Put().
		Namespace(c.ns).
		Resource("scales").
		Name(scale.Name).
		VersionedParams(&opts, scheme.ParameterCodec).
		Body(scale).
		Do(ctx).
		Into(result)
	return
}

// Delete takes name of the scale and deletes it. Returns an error if one occurs.
func (c *scales) Delete(ctx context.Context, name string, opts v1.DeleteOptions) error {
	return c.client.Delete().
		Namespace(c.ns).
		Resource("scales").
		Name(name).
		Body(&opts).
		Do(ctx).
		Error()
}

// DeleteCollection deletes a collection of objects.
func (c *scales) DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error {
	var timeout time.Duration
	if listOpts.TimeoutSeconds != nil {
		timeout = time.Duration(*listOpts.TimeoutSeconds) * time.Second
	}
	return c.client.Delete().
		Namespace(c.ns).
		Resource("scales").
		VersionedParams(&listOpts, scheme.ParameterCodec).
		Timeout(timeout).
		Body(&opts).
		Do(ctx).
		Error()
}

// Patch applies the patch and returns the patched scale.
func (c *scales) Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1alpha1.Scale, err error) {
	result = &v1alpha1.Scale{}
	err = c.client.Patch(pt).
		Namespace(c.ns).
		Resource("scales").
		Name(name).
		SubResource(subresources...).
		VersionedParams(&opts, scheme.ParameterCodec).
		Body(data).
		Do(ctx).
		Into(result)
	return
}
